<?php
/**
 * Post types file.
 *
 * @package Cheshalo
 */

namespace CHESHCORE;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

/**
 * Post types class.
 */
class Post_Types {
	/**
	 * Instance.
	 *
	 * @var null
	 */
	public static $instance = null;

	/**
	 * Instance.
	 *
	 * @return Post_Types|null
	 */
	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_layout' ), 1 );
		add_action( 'init', array( $this, 'linked_variations' ), 1 );
		add_action( 'init', array( $this, 'bought_together' ), 1 );
		add_action( 'init', array( $this, 'register_discounts' ), 1 );
		add_action( 'init', array( $this, 'register_free_gifts' ), 1 );
		add_action( 'init', array( $this, 'register_estimate_delivery' ), 1 );
		add_action( 'init', array( $this, 'register_abandoned_cart' ), 1 );
	}

	/**
	 * Register layout post type.
	 */
	public function register_layout() {
		register_post_type(
			'cheshalo_layout',
			array(
				'label'              => esc_html__( 'Layouts', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Layouts', 'cheshalo' ),
					'singular_name' => esc_html__( 'Layout', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Layouts', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New', 'cheshalo' ),
				),
				'supports'           => array( 'title', 'editor' ),
				'hierarchical'       => false,
				'public'             => true,
				'menu_position'      => 32,
				'menu_icon'          => 'dashicons-format-gallery',
				'publicly_queryable' => is_user_logged_in(),
				'show_in_rest'       => true,
				'capability_type'    => 'page',
			)
		);
	}

	/**
	 * Register layout post type.
	 */
	public function linked_variations() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'linked_variations', 1 ) ) {
			return;
		}

		register_post_type(
			'cheshalo_woo_lv',
			array(
				'label'              => esc_html__( 'Linked Variations', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Linked Variations', 'cheshalo' ),
					'singular_name' => esc_html__( 'Linked Variations', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Linked Variations', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New', 'cheshalo' ),
				),
				'supports'           => array( 'title' ),
				'hierarchical'       => false,
				'public'             => true,
				'show_in_menu'       => 'edit.php?post_type=product',
				'publicly_queryable' => false,
				'show_in_rest'       => true,
				'capability_type'    => 'product',
			)
		);
	}

	/**
	 * Register frequently bought together post type.
	 */
	public function bought_together() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'bought_together_enabled', 1 ) ) {
			return;
		}

		register_post_type(
			'cheshalo_woo_fbt',
			array(
				'label'              => esc_html__( 'Frequently Bought Together', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Frequently Bought Together', 'cheshalo' ),
					'singular_name' => esc_html__( 'Frequently Bought Together', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Frequently Bought Together', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New', 'cheshalo' ),
				),
				'supports'           => array( 'title' ),
				'hierarchical'       => false,
				'public'             => true,
				'show_in_menu'       => 'edit.php?post_type=product',
				'publicly_queryable' => false,
				'show_in_rest'       => true,
				'capability_type'    => 'product',
			)
		);
	}

	/**
	 * Register Dynamic Pricing & Discounts post type.
	 */
	public function register_discounts() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'discounts_enabled', 0 ) ) {
			return;
		}

		register_post_type(
			'wd_woo_discounts',
			array(
				'label'              => esc_html__( 'Dynamic Discounts', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Dynamic Discounts', 'cheshalo' ),
					'singular_name' => esc_html__( 'Dynamic Discount', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Dynamic Discounts', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New Rule', 'cheshalo' ),
					'edit_item'     => esc_html__( 'Edit Discount Rule', 'cheshalo' ),
				),
				'supports'           => array( 'title' ),
				'hierarchical'       => false,
				'public'             => true,
				'show_in_menu'       => 'edit.php?post_type=product',
				'publicly_queryable' => false,
				'show_in_rest'       => true,
				'capability_type'    => 'product',
			)
		);
	}

	/**
	 * Register Free gifts post type.
	 */
	public function register_free_gifts() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'free_gifts_enabled', 0 ) ) {
			return;
		}

		register_post_type(
			'wd_woo_free_gifts',
			array(
				'label'              => esc_html__( 'Free Gifts', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Free Gifts', 'cheshalo' ),
					'singular_name' => esc_html__( 'Free Gift', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Free Gifts', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New Gift', 'cheshalo' ),
					'edit_item'     => esc_html__( 'Edit Gift Rule', 'cheshalo' ),
				),
				'supports'           => array( 'title' ),
				'hierarchical'       => false,
				'public'             => true,
				'show_in_menu'       => 'edit.php?post_type=product',
				'publicly_queryable' => false,
				'show_in_rest'       => true,
				'capability_type'    => 'product',
			)
		);
	}

	/**
	 * Register Estimate Delivery post type.
	 */
	public function register_estimate_delivery() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'estimate_delivery_enabled', 0 ) ) {
			return;
		}

		register_post_type(
			'wd_woo_est_del',
			array(
				'label'              => esc_html__( 'Estimate Delivery', 'cheshalo' ),
				'labels'             => array(
					'name'          => esc_html__( 'Estimate Delivery', 'cheshalo' ),
					'singular_name' => esc_html__( 'Estimate Delivery', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Estimate Delivery', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New Rule', 'cheshalo' ),
					'edit_item'     => esc_html__( 'Edit Estimate Delivery Rule', 'cheshalo' ),
				),
				'supports'           => array( 'title' ),
				'hierarchical'       => false,
				'public'             => true,
				'show_in_menu'       => 'edit.php?post_type=product',
				'publicly_queryable' => false,
				'show_in_rest'       => true,
				'capability_type'    => 'product',
			)
		);
	}

	/**
	 * Register Abandoned Cart post type.
	 */
	public function register_abandoned_cart() {
		if ( ! function_exists( 'cheshalo_get_opt' ) || ! cheshalo_get_opt( 'cart_recovery_enabled' ) ) {
			return;
		}

		register_post_type(
			'wd_abandoned_cart',
			array(
				'label'               => esc_html__( 'Carts', 'cheshalo' ),
				'labels'              => array(
					'name'          => esc_html__( 'Abandoned Cart', 'cheshalo' ),
					'singular_name' => esc_html__( 'Abandoned Cart', 'cheshalo' ),
					'menu_name'     => esc_html__( 'Abandoned Cart', 'cheshalo' ),
					'add_new'       => esc_html__( 'Add New Abandoned Cart', 'cheshalo' ),
					'add_new_item'  => esc_html__( 'Add New Abandoned Cart', 'cheshalo' ),
					'edit_item'     => esc_html__( 'Abandoned cart information', 'cheshalo' ),
				),
				'supports'            => array( '' ),
				'hierarchical'        => false,
				'public'              => false,
				'show_ui'             => true,
				'show_in_menu'        => false,
				'exclude_from_search' => true,
				'capability_type'     => 'post',
				'capabilities'        => array( 'create_posts' => false ),
				'map_meta_cap'        => true,
			)
		);
	}
}

Post_Types::get_instance();
