<?php
/**
 * Rank Math.
 *
 * @package Cheshalo
 */

if ( ! defined( 'RANK_MATH_VERSION' ) ) {
	return;
}

if ( ! function_exists( 'cheshalo_rank_math_excluded_post_types' ) ) {
	/**
	 * Exclude CheshAlo layout post type from Rank Math sitemap.
	 *
	 * @param array $post_type Post type.
	 * @return array
	 */
	function cheshalo_rank_math_excluded_post_types( $post_type ) {
		if ( isset( $post_type['cheshalo_layout'] ) ) {
			unset( $post_type['cheshalo_layout'] );
		}

		return $post_type;
	}

	add_filter( 'rank_math/excluded_post_types', 'cheshalo_rank_math_excluded_post_types' );
}

if ( ! function_exists( 'cheshalo_rank_math_update_shortcode_title' ) ) {
	/**
	 * Update CheshAlo title shortcode to work with Rank Math.
	 *
	 * @return void
	 */
	function cheshalo_rank_math_update_shortcode_title() {
		if ( 'wpb' !== cheshalo_get_current_page_builder() ) {
			return;
		}

		?>
		<script type="text/javascript">
			(function ($) {
				wp.hooks.addFilter('rank_math_content', 'rank-math', function (content) {
					return content.replace(/\[cheshalo_title\s+([^\]]+)\]/g, function (match, attrString) {
						const parseAttributes = (str) => {
							const attrs = {};
							const regex = /(\w+)=(["'])(.*?)\2/g;
							let m;
							while ((m = regex.exec(str)) !== null) {
								attrs[m[1]] = m[3];
							}
							return attrs;
						};

						const attrs = parseAttributes(attrString);

						const tag = attrs.tag || 'h4';

						if (attrs.title) {
							const wrappedTitle = `<${tag}>${attrs.title}</${tag}>`;

							const newAttrString = attrString.replace(/title=(["'])(.*?)\1/, `title="${wrappedTitle}"`);

							return `[cheshalo_title ${newAttrString}]`;
						}

						return match;
					});
				}, 9);
			})(jQuery);
		</script>
		<?php
	}

	add_filter( 'admin_footer-post.php', 'cheshalo_rank_math_update_shortcode_title' );
}
